/**
 * This file is part of OpenMediaVault-autoshutdown.
 *
 * @license   http://www.gnu.org/licenses/gpl.html GPL Version 3
 * @author    Marcel Beck <marcel.beck@mbeck.org>
 * @copyright Copyright (c) 2012 Marcel Beck
 *
 * OpenMediaVault is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * OpenMediaVault is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenMediaVault. If not, see <http://www.gnu.org/licenses/>.
 */
	// require("js/omv/NavigationPanel.js")
	// require("js/omv/data/DataProxy.js")
	// require("js/omv/FormPanelExt.js")
	// require("js/omv/form/plugins/FieldInfo.js")

	// require("js/omv/module/autoshutdown/navigation.js")
	// require("js/omv/module/autoshutdown/utils.js")

Ext.ns("OMV.Module.Services.Autoshutdown.Admin.Dialog");

/**
 * @class OMV.Module.Services.Autoshutdown.Admin.Dialog.Ports
 * Defaults to FALSE.
 */
OMV.Module.Services.Autoshutdown.Admin.Dialog.Ports = function (config) {
	var initialConfig = {
		title      :_("Edit network Ports"),
		width      :500,
		height     :300,
		layout     :"fit",
		modal      :true,
		border     :true,
		buttonAlign:"center",
		readOnly   :false
	};
	Ext.apply(initialConfig, config);
	OMV.Module.Services.Autoshutdown.Admin.Dialog.Ports.superclass.constructor.call(this, initialConfig);
	this.addEvents(
					/**
					 * Fires after the submission has been finished successful.
					 */
					"submit"
	);
};
Ext.extend(OMV.Module.Services.Autoshutdown.Admin.Dialog.Ports, Ext.Window, {
	initComponent:function () {
		this.grid = new OMV.grid.GridPanel({
			bodyCssClass:"x-grid3-without-dirty-cell",
			stateId     :"3b600040-81b0-11e1-b0c4-0800200c9a66",
			colModel    :new Ext.grid.ColumnModel({
				columns:[
					{
						header   :_("Protocol"),
						sortable :true,
						dataIndex:"protocol",
						id       :"protocol",
						align    :"center"
					},
					{
						header   :_("Port"),
						sortable :true,
						dataIndex:"port",
						id       :"port"
					},
					{
						header   :_("Program"),
						dataIndex:"program",
						id       :"program",
						align    :"center"
					}
					,
					{
						header   :_("Check"),
						dataIndex:"check",
						id       :"check",
						align    :"center",
						renderer :this.checkBoxRenderer,
						scope    :this
					}
				]
			}),
			store       :new OMV.data.Store({
				autoLoad  :true,
				remoteSort:false,
				proxy     :new OMV.data.DataProxy({"service":"Autoshutdown", "method":"getPorts"}),
				reader    :new Ext.data.JsonReader({
					fields:[
						{ name:"protocol" },
						{ name:"port" },
						{ name:"program" },
						{ name:"check"}
					]
				})
			})
		});
		Ext.apply(this, {
			buttons:[
				{
					text    :_("OK"),
					handler :this.cbOkBtnHdl,
					scope   :this,
					disabled:this.readOnly
				},
				{
					text   :_("Cancel"),
					handler:this.cbCancelBtnHdl,
					scope  :this
				}
			],
			items  :[ this.grid ]
		});
		OMV.Module.Services.Autoshutdown.Admin.Dialog.Ports.superclass.initComponent.apply(this, arguments);
		// Register event handler
		this.grid.on("cellclick", this.onCellClick, this);
	},

	/**
	 * @method cbOkBtnHdl
	 * Method that is called when the 'OK' button is pressed.
	 */
	cbOkBtnHdl:function () {
		this.doSubmit();
	},

	/**
	 * @method cbCancelBtnHdl
	 * Method that is called when the 'Cancel' button is pressed.
	 */
	cbCancelBtnHdl:function () {
		this.close();
	},

	/**
	 * @method doLoad
	 * Load the grid content.
	 */
	doLoad:function () {
		this.grid.store.load();
	},

	doSubmit:function () {
		// Display waiting dialog
		OMV.MessageBox.wait(null, _("Saving ..."));
		// Prepare RPC content
		var records = this.grid.store.getRange();
		var values = {ports:[]};
		for (var i = 0; i < records.length; i++) {
			var record = records[i];
			values.ports.push({
				protocol:record.get('protocol'),
				port    :record.get('port'),
				check   :record.get('check')
			});
		}
		OMV.Ajax.request(this.cbSubmitHdl, this, "Autoshutdown", "setPorts", values);
	},

	cbSubmitHdl:function (id, response, error) {
		OMV.MessageBox.updateProgress(1);
		OMV.MessageBox.hide();
		if (error === null) {
			this.fireEvent("submit", this);
			this.close();
		}
		else {
			OMV.MessageBox.error(null, error);
		}
	},

	/**
	 * Handle grid cell clicks. Only process columns with a checkbox.
	 */
	onCellClick:function (grid, rowIndex, columnIndex, e) {
		if (this.readOnly) {
			return;
		}
		var record = this.grid.store.getAt(rowIndex);
		var dataIndex = this.grid.getColumnModel().getDataIndex(columnIndex);
		var dataIndices = [ "check" ];
		if (-1 !== dataIndices.indexOf(dataIndex)) {
			// Clear all selections
			for (var i = 0; i < dataIndices.length; i++) {
				// Skip current clicked record field, otherwise unselection
				// of cells will not work
				if (dataIndices[i] === dataIndex) {
					continue;
				}
				// Set to 'false' per default
				record.set(dataIndices[i], false);
			}
			// Set new selection
			record.set(dataIndex, !record.get(dataIndex));
		}
	},

	/**
	 * Render a checkbox in the given grid cell.
	 */
	checkBoxRenderer:function (val, cell, record, row, col, store) {
		cell.css += " x-grid3-check-col-td";
		return '<div class="x-grid3-check-col' + ((true === val) ? '-on' : '') + ' x-grid3-cc-' + this.id + '">&#160;</div>';
	}
});